<#
 # Generates a powerpoint file from a list of tableau urls.
 # 
 # @author Derrick Austin <https://www.interworks.com/blog/daustin>
 #>

# Base path of your script.
$base = 'C:\Users\daustin\Desktop\Powerpoint\';

# Tableau Server URL
$ts_url = 'https://tableau.mysite.com';

# Path to your tabcmd setup
$tabcmd_path = "C:\Program Files\Tableau\Tableau Server\9.1\extras\Command Line Utility\";

# URLs to Pull into the PPTX - Add a ? to the end of these, if they do not have one already.
$urls = @(
    'views/myWorbook/Url1?',
    'views/myWorbook/Url2?'
);

$work_dir      = $base + '\temp\';
$input_pres    = $base + '\AnalyticsPPTBase.pptx';
$output_folder = $base + '\output\';

$env:path += ";" + $tabcmd_path;
Add-Type -AssemblyName Office;

# These could be pulled from elsewhere, they probably should not be hardcoded.
$username = "daustin";
$password = "mypasswordhere"
$mysite   = "daustin";

# Login - use the second version instead if you do not have a site.
tabcmd login -s $ts_url -u $username -p $password -t $mysite --no-certcheck;
#tabcmd login -s $ts_url -u $username -p $password --no-certcheck;

if ($LastExitCode -ne 0) {
    echo "Login failed.  Goodbye.";
    break;
}

$PPT         = New-Object -ComObject powerpoint.application;
$ori         = [Microsoft.Office.Core.MsoTextOrientation]::msoTextOrientationHorizontal;
$my_ppt      = $PPT.Presentations.Open($input_pres, $false, $false, $false);
$num_slides  = $my_ppt.Slides.Count - 1;
$cover       = $my_ppt.Slides.Item(1);
$base_slide  = $my_ppt.Slides.Item(2);
$template    = $base_slide.CustomLayout;
$datestr     = Get-Date -f "MMMM yyyy";
$base_slide.delete();

# Generates the RGB color for the font you want to use.
$rgb = [long] (84 + (84 * 256) + (84 * 65536));

# Adds the date generated to the first slide
$tb = $cover.Shapes.AddTextbox($ori, 23, 285, 405, 70);
$tb.TextFrame.TextRange.Text = $datestr.ToUpper();
$tb.TextFrame.TextRange.Font.NameAscii = 'Trebuchet MS';
$tb.TextFrame.TextRange.Font.Size = 16;
$tb.TextFrame.TextRange.Font.Color.RGB = $rgb;
$tb.Fill.Transparency = 1;

foreach ($url in $urls) {
    $filename  = $work_dir + "temp.png";
    
    $to_get = $url;
    $to_get = $to_get.Replace('?', ".png?");
    $to_get = $to_get.Replace('&amp;', "&");
    
    tabcmd get $to_get -f $filename --no-certcheck;
    
    $num_slides = $num_slides + 1;
    $new_slide  = $my_ppt.Slides.AddSlide($num_slides, $template);
    $new_pic    = $new_slide.shapes.AddPicture($filename, $false, $true, 0, 50);
    $new_pic.Title = 'Optional Title Here';
    $new_slide.Shapes.title.TextFrame.TextRange.Text = 'Optional Title Here';
    
    $new_pic.LockAspectRatio = $false;
    $new_pic.Width  = $new_slide.CustomLayout.Width + 1;
    $new_pic.Height = 470;
}

$name = $output_folder + "Export";
$my_ppt.SaveCopyAs($name);
$my_ppt.Close();